@@ -1,6 +1,6 @@
 from typing import Callable, TypeVar
 
-from amino import Just
+from amino import Just, L, _, Empty
 from amino.tc.monad import Monad
 from amino.tc.base import ImplicitInstances
 from amino.lazy import lazy
@@ -22,15 +22,14 @@ class TaskInstances(ImplicitInstances):
 class TaskMonad(Monad):
 
     def pure(self, a: A):
-        return Task(lambda: a, as_string=Just(a))
+        return Task.now(a)
 
     def flat_map(self, fa: Task[A], f: Callable[[A], Task[B]]) -> Task[B]:
-        s = '{}.flat_map({})'.format(fa.as_string, lambda_str(f))
-        return Task(lambda: f(fa.run()).run(), 5, Just(s))
+        return fa.flat_map(f)
 
     def map(self, fa: Task[A], f: Callable[[A], B]) -> Task[B]:
-        s = '{}.map({})'.format(fa.as_string, lambda_str(f))
-        return Task(lambda: f(fa.run()), 5, Just(s))
-
+        s = 'map({})'.format(lambda_str(f))
+        mapper = L(f)(_) >> L(Task.now)(_)
+        return fa.flat_map(mapper, Empty(), Just(s))
 
 __all__ = ('TaskInstances',)
